@@ -140,18 +140,18 @@ test -d /usr/local/share/excludes && excludes_entry=$(entry \
     $"Edit Exclude Files")
 
 if test -x /usr/sbin/synaptic; then synaptic_entry=$(entry \
-    $ICONS2/synaptic.png \
+    $ICONS/synaptic.png \
     "gksu synaptic &" \
     $"Manage Packages")
 
 elif test -x /usr/local/bin/cli-aptiX; then synaptic_entry=$(entry \
-    $ICONS2/synaptic.png \
+    $ICONS/synaptic.png \
     "desktop-defaults-run -t sudo /usr/local/bin/cli-aptiX --pause &" \
     $"Manage Packages")
 fi
 
 test -x  /usr/sbin/bootrepair && bootrepair_entry=$(entry \
-    $ICONS2/bootrepair.png \
+    $ICONS/bootrepair.png \
     "gksu bootrepair &" \
     $"Boot Repair")
 
@@ -174,7 +174,7 @@ test -x $backup_prog  && backup_entry=$(entry \
 
 equalizer_prog=/usr/bin/alsamixer
 test -x $equalizer_prog  && equalizer_entry=$(entry \
-    $ICONS2/alsamixer-equalizer.png \
+    $ICONS/alsamixer-equalizer.png \
     "desktop-defaults-run -t alsamixer -D equal &" \
     $"Alsamixer Equalizer")
 
@@ -186,7 +186,7 @@ test -x $unetbootin_prog  && unetbootin_entry=$(entry \
 
 printer_prog=/usr/bin/system-config-printer
 test -x $printer_prog  && printer_entry=$(entry \
-    $ICONS2/hplj1020_icon.png \
+    $ICONS/printer.png \
     "system-config-printer &" \
     $"Print Settings")
 
@@ -216,7 +216,7 @@ test -x $wallpaper_prog && wallpaper_entry=$(entry \
 
 conky_prog=/usr/bin/conky
 test -x $conky_prog && test -w $HOME/.conkyrc && conky_entry=$(entry \
-    $ICONS/utilities-system-monitor.png \
+    $ICONS/conky.png \
     "desktop-defaults-run -te $HOME/.conkyrc &" \
     $"Edit System Monitor (Conky)")
 
@@ -253,7 +253,7 @@ test -x $tzdata_prog && test -d $tzdata_dir && tzdata_entry=$(entry \
 
 ceni_prog=/usr/bin/ceni
 test -x $ceni_prog && ceni_entry=$(entry \
-    $ICONS/network-wired.png \
+    $ICONS/ceni.png \
     "desktop-defaults-run -t sudo ceni &" \
     $"Network Interfaces (Ceni)")
 
@@ -277,7 +277,7 @@ test -x $disconnectshares_prog && disconnectshares_entry=$(entry \
 
 droopy_prog=/usr/local/bin/droopy.sh
 test -x $droopy_prog && droopy_entry=$(entry \
-    $ICONS2/droopy.png \
+    $ICONS/droopy.png \
     "droopy.sh &" \
     $"Droopy (File Sharing)")
 
@@ -301,13 +301,13 @@ test -x $sshconduit_prog && sshconduit_entry=$(entry \
 
 gnomeppp_prog=/usr/bin/gnome-ppp
 test -x $gnomeppp_prog && gnomeppp_entry=$(entry \
-    $ICONS/internet-telephony.png \
+    $ICONS/gnome-ppp.png \
     "gnome-ppp &" \
     $"Dial-Up Configuaration (GNOME PPP)")
 
 wpasupplicant_prog=/usr/sbin/wpa_gui
 test -x $wpasupplicant_prog && wpasupplicant_entry=$(entry \
-    $ICONS/nm-device-wireless.png \
+    $ICONS/wpa_gui.png \
     "/usr/sbin/wpa_gui &" \
     $"WPA Supplicant Configuration")
 
@@ -319,7 +319,7 @@ test -x $pppoeconf_prog && pppoeconf_entry=$(entry \
 
 adblock_prog=/usr/local/bin/block-advert.sh
 test -x $adblock_prog && adblock_entry=$(entry \
-    $ICONS2/advert-block.png \
+    $ICONS/advert-block.png \
     "gksu block-advert.sh &" \
     $"Adblock")
 
@@ -349,7 +349,7 @@ test -x $arandr_prog && arandr_entry=$(entry \
 
 gksu_prog=/usr/bin/gksu-properties
 test -x $gksu_prog && gksu_entry=$(entry \
-    $ICONS2/gksu.png \
+    $ICONS/gksu.png \
     "gksu-properties &" \
     $"Password Prompt (su/sudo)")
 
@@ -387,13 +387,13 @@ liveusb_prog_g=/usr/bin/live-usb-maker-gui-antix
 liveusb_prog=/usr/local/bin/live-usb-maker
 if test -x $liveusb_prog_g; then
 liveusb_entry=$(entry \
-    $ICONS/usb-creator.png \
+    $ICONS/live-usb-maker.png \
     "gksu live-usb-maker-gui-antix &" \
     $"Live USB Maker (gui)")
 
 elif test -x $liveusb_prog; then
 liveusb_entry=$(entry \
-    $ICONS/usb-creator.png \
+    $ICONS/live-usb-maker.png \
      "desktop-defaults-run sudo &live-usb-maker &" \
      $"Live USB Maker (cli)")
 fi
@@ -430,7 +430,7 @@ test -x $setdpi_prog && setdpi_entry=$(entry \
 
 inxi_prog=/usr/local/bin/inxi-gui
 test -x $inxi_prog && inxi_entry=$(entry \
-    $ICONS2/info_blue.png \
+    $ICONS/info_blue.png \
     "inxi-gui &" \
     $"PC Information")
 
@@ -442,7 +442,7 @@ test -x $mouse_prog && mouse_entry=$(entry \
 
 soundcard_prog=/usr/local/bin/alsa-set-default-card
 test -x $soundcard_prog && soundcard_entry=$(entry \
-    $ICONS2/soundcard.png \
+    $ICONS/soundcard.png \
     "alsa-set-default-card &" \
     $"Sound Card Chooser")
 
@@ -489,13 +489,13 @@ test -x $usermanager_prog && usermanager_entry=$(entry \
 
 galternatives_prog=/usr/bin/galternatives
 test -x $galternatives_prog && galternatives_entry=$(entry \
-    $ICONS2/galternatives.png \
+    $ICONS/galternatives.png \
     "galternatives &" \
     $"Alternatives Configurator")
 
 codecs_prog=/usr/sbin/codecs
 test -x $codecs_prog && codecs_entry=$(entry \
-    $ICONS2/codecs.png \
+    $ICONS/codecs.png \
     "gksu codecs &" \
     $"Codecs Installer")
 
@@ -519,12 +519,12 @@ test -x $repomanager_prog && repomanager_entry=$(entry \
 
 which backlight-brightness &>/dev/null && [ -n "$(ls /sys/class/backlight 2>/dev/null)" ] \
     && backlight_entry=$(entry \
-    $ICONS2/backlight-brightness.png \
+    $ICONS/backlight-brightness.png \
     "desktop-defaults-run -t backlight-brightness &" \
     $"Backlight Brightness")
 
 [ -e /etc/live/config/save-persist -o -e /etc/live/config/persist-save.conf ]  && persist_save=$(entry \
-    $ICONS2/save.png \
+    $ICONS/save.png \
     "gksu persist-save &" \
     $"Save Root Persistence")
 
